summaryrefslogtreecommitdiffstats
path: root/krusader/Panel
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:12:12 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:12:12 -0600
commit527c1d6eee022fbe0fed30d64ca6695c48925be2 (patch)
tree0ce098887e1f76dcba419110ebe925c51363604a /krusader/Panel
parentb8fb4538e9eddfeb9eb0fa8def496f58cb7a9bf1 (diff)
downloadkrusader-527c1d6eee022fbe0fed30d64ca6695c48925be2.tar.gz
krusader-527c1d6eee022fbe0fed30d64ca6695c48925be2.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'krusader/Panel')
-rw-r--r--krusader/Panel/krbriefview.cpp30
-rw-r--r--krusader/Panel/krbriefview.h4
-rw-r--r--krusader/Panel/krbriefviewitem.cpp2
-rw-r--r--krusader/Panel/krcalcspacedialog.cpp2
-rw-r--r--krusader/Panel/krcalcspacedialog.h8
-rw-r--r--krusader/Panel/krdetailedview.cpp32
-rw-r--r--krusader/Panel/krdetailedview.h6
-rw-r--r--krusader/Panel/krdetailedviewitem.cpp6
-rw-r--r--krusader/Panel/krpopupmenu.cpp4
-rw-r--r--krusader/Panel/krpreviewpopup.cpp6
-rw-r--r--krusader/Panel/krview.cpp16
-rw-r--r--krusader/Panel/krview.h14
-rw-r--r--krusader/Panel/krviewitem.cpp4
-rw-r--r--krusader/Panel/krviewitem.h2
-rw-r--r--krusader/Panel/listpanel.cpp36
-rw-r--r--krusader/Panel/listpanel.h10
-rwxr-xr-xkrusader/Panel/panelfunc.cpp46
-rw-r--r--krusader/Panel/panelfunc.h2
-rw-r--r--krusader/Panel/panelpopup.cpp8
-rw-r--r--krusader/Panel/panelpopup.h2
20 files changed, 120 insertions, 120 deletions
diff --git a/krusader/Panel/krbriefview.h b/krusader/Panel/krbriefview.h
index e53d8fd..8d7f6b6 100644
--- a/krusader/Panel/krbriefview.h
+++ b/krusader/Panel/krbriefview.h
@@ -58,7 +58,7 @@ class KrBriefView: public KIconView, public KrView {
Q_OBJECT
public:
- KrBriefView( TQHeader *header, TQWidget *parent, bool &left, KConfig *cfg = krConfig, const char *name = 0 );
+ KrBriefView( TQHeader *header, TQWidget *parent, bool &left, TDEConfig *cfg = krConfig, const char *name = 0 );
virtual ~KrBriefView();
virtual inline KrViewItem *getFirst() { return dynamic_cast<KrViewItem*>( firstItem() ); }
virtual inline KrViewItem *getLast() { return dynamic_cast<KrViewItem*>( lastItem() ); }
@@ -81,7 +81,7 @@ public:
virtual void prepareForPassive();
virtual void saveSettings() {}
virtual void restoreSettings() {}
- virtual TQString nameInKConfig() {return _nameInKConfig;}
+ virtual TQString nameInTDEConfig() {return _nameInTDEConfig;}
virtual void resizeEvent ( TQResizeEvent * );
signals:
diff --git a/krusader/Panel/krbriefviewitem.cpp b/krusader/Panel/krbriefviewitem.cpp
index 6626ffe..230f8d2 100644
--- a/krusader/Panel/krbriefviewitem.cpp
+++ b/krusader/Panel/krbriefviewitem.cpp
@@ -23,7 +23,7 @@ KrBriefViewItem::KrBriefViewItem(KrBriefView *parent, TQIconViewItem *after, vfi
initiated = false;
// get the expected height of an item - should be done only once
if (expHeight == 0) {
- KConfigGroupSaver svr(krConfig, "Look&Feel");
+ TDEConfigGroupSaver svr(krConfig, "Look&Feel");
expHeight = 2 + (krConfig->readEntry("Filelist Icon Size",_FilelistIconSize)).toInt();
}
if( PROPS->displayIcons )
diff --git a/krusader/Panel/krcalcspacedialog.cpp b/krusader/Panel/krcalcspacedialog.cpp
index fbd9538..802c5ec 100644
--- a/krusader/Panel/krcalcspacedialog.cpp
+++ b/krusader/Panel/krcalcspacedialog.cpp
@@ -144,7 +144,7 @@ void KrCalcSpaceDialog::showResult(){
if (!m_thread) return;
TQString msg;
TQString fileName = ( ( m_thread->getItems().count() == 1 ) ? ( i18n( "Name: " ) + m_thread->getItems().first() + "\n" ) : TQString( "" ) );
- msg = fileName + i18n( "Total occupied space: %1").arg( KIO::convertSize( m_thread->getTotalSize() ) );
+ msg = fileName + i18n( "Total occupied space: %1").arg( TDEIO::convertSize( m_thread->getTotalSize() ) );
if (m_thread->getTotalSize() >= 1024)
msg += " (" + KRpermHandler::parseSize( m_thread->getTotalSize() ) + "bytes)";
msg += "\n";
diff --git a/krusader/Panel/krcalcspacedialog.h b/krusader/Panel/krcalcspacedialog.h
index f729ddb..27bafb3 100644
--- a/krusader/Panel/krcalcspacedialog.h
+++ b/krusader/Panel/krcalcspacedialog.h
@@ -58,7 +58,7 @@ class KrCalcSpaceDialog : public KDialogBase{
needed. Creator must call finished(), if the thread is no longer needed.
*/
class CalcThread : public TQThread{
- KIO::filesize_t m_totalSize, m_currentSize;
+ TDEIO::filesize_t m_totalSize, m_currentSize;
unsigned long m_totalFiles;
unsigned long m_totalDirs;
const TQStringList m_items;
@@ -70,7 +70,7 @@ class KrCalcSpaceDialog : public KDialogBase{
bool m_stop;
void cleanUp(); // Deletes this, if possible
public:
- KIO::filesize_t getTotalSize() const {return m_totalSize + m_currentSize;} // the result
+ TDEIO::filesize_t getTotalSize() const {return m_totalSize + m_currentSize;} // the result
unsigned long getTotalFiles() const {return m_totalFiles;} // the result
unsigned long getTotalDirs() const {return m_totalDirs;} // the result
const TQStringList & getItems() const {return m_items;} // list of directories to calculate
@@ -87,7 +87,7 @@ class KrCalcSpaceDialog : public KDialogBase{
int m_timerCounter; // internal counter. The timer runs faster as the rehresh (see comment there)
void calculationFinished(); // called if the calulation is done
void showResult(); // show the current result in teh dialog
- static void setDirSize(KrDetailedViewItem * viewItem, KIO::filesize_t size) {viewItem->setSize(size);}
+ static void setDirSize(KrDetailedViewItem * viewItem, TDEIO::filesize_t size) {viewItem->setSize(size);}
protected slots:
void timer(); // poll timer was fired
void slotCancel(); // cancel was pressed
@@ -95,7 +95,7 @@ public:
// autoclose: wait 3 sec. before showing the dialog. Close it, when done
KrCalcSpaceDialog(TQWidget *parent, ListPanel * panel, const TQStringList & items, bool autoclose);
~KrCalcSpaceDialog();
- KIO::filesize_t getTotalSize() const {return m_thread->getTotalSize();} // the result
+ TDEIO::filesize_t getTotalSize() const {return m_thread->getTotalSize();} // the result
unsigned long getTotalFiles() const {return m_thread->getTotalFiles();} // the result
unsigned long getTotalDirs() const {return m_thread->getTotalDirs();} // the result
bool wasCanceled() const {return m_canceled;} // cancel was pressed; result is probably wrong
diff --git a/krusader/Panel/krdetailedview.h b/krusader/Panel/krdetailedview.h
index 6d902ea..8fa02c9 100644
--- a/krusader/Panel/krdetailedview.h
+++ b/krusader/Panel/krdetailedview.h
@@ -75,7 +75,7 @@ class KrDetailedView : public KListView, public KrView {
friend class KrDetailedViewItem;
public:
- KrDetailedView( TQWidget *parent, bool &left, KConfig *cfg = krConfig, const char *name = 0 );
+ KrDetailedView( TQWidget *parent, bool &left, TDEConfig *cfg = krConfig, const char *name = 0 );
virtual ~KrDetailedView();
virtual int column( KrDetailedViewProperties::ColumnType type );
virtual inline KrViewItem *getFirst() { return dynamic_cast<KrViewItem*>( firstChild() ); }
@@ -96,8 +96,8 @@ public:
virtual void setSortMode( KrViewProperties::SortSpec mode );
virtual void prepareForActive();
virtual void prepareForPassive();
- virtual inline void saveSettings() { KListView::saveLayout( _config, nameInKConfig() ); }
- virtual inline void restoreSettings() { KListView::restoreLayout( _config, nameInKConfig() ); }
+ virtual inline void saveSettings() { KListView::saveLayout( _config, nameInTDEConfig() ); }
+ virtual inline void restoreSettings() { KListView::restoreLayout( _config, nameInTDEConfig() ); }
signals:
void middleButtonClicked( KrViewItem *item );
diff --git a/krusader/Panel/krdetailedviewitem.cpp b/krusader/Panel/krdetailedviewitem.cpp
index 2a0da8e..2c17c9f 100644
--- a/krusader/Panel/krdetailedviewitem.cpp
+++ b/krusader/Panel/krdetailedviewitem.cpp
@@ -63,7 +63,7 @@ KrDetailedViewItem::KrDetailedViewItem(KrDetailedView *parent, TQListViewItem *a
initiated = false;
// get the expected height of an item - should be done only once
if (expHeight == 0) {
- KConfigGroupSaver svr(krConfig, "Look&Feel");
+ TDEConfigGroupSaver svr(krConfig, "Look&Feel");
expHeight = 2 + (krConfig->readEntry("Filelist Icon Size",_FilelistIconSize)).toInt();
}
@@ -108,7 +108,7 @@ void KrDetailedViewItem::repaintItem() {
}
if ((id = COLUMN(Size)) != -1) {
if (_vf->vfile_isDir() && _vf->vfile_getSize() <= 0) setText(id, i18n("<DIR>"));
- else setText(id, PROPS->humanReadableSize ? KIO::convertSize(_vf->vfile_getSize())+" " :
+ else setText(id, PROPS->humanReadableSize ? TDEIO::convertSize(_vf->vfile_getSize())+" " :
KRpermHandler::parseSize(_vf->vfile_getSize())+" ");
}
@@ -160,7 +160,7 @@ void KrDetailedViewItem::repaintItem() {
#endif
}
-TQString num2qstring(KIO::filesize_t num){
+TQString num2qstring(TDEIO::filesize_t num){
TQString buf;
buf.sprintf("%025llu",num);
return buf;
diff --git a/krusader/Panel/krpopupmenu.cpp b/krusader/Panel/krpopupmenu.cpp
index 2782bc4..cd323b0 100644
--- a/krusader/Panel/krpopupmenu.cpp
+++ b/krusader/Panel/krpopupmenu.cpp
@@ -137,7 +137,7 @@ KrPopupMenu::KrPopupMenu(ListPanel *thePanel, TQWidget *parent) : KPopupMenu(par
insertItem( i18n( "Rename" ), RENAME_ID );
// -------- MOVE TO TRASH
- KConfigGroupSaver saver(krConfig, "General");
+ TDEConfigGroupSaver saver(krConfig, "General");
bool trash = krConfig->readBoolEntry( "Move To Trash", _MoveToTrash );
if( trash )
insertItem( i18n( "Move to Trash" ), TRASH_ID );
@@ -326,7 +326,7 @@ void KrPopupMenu::performAction(int id) {
chdir( panel->func->files() ->vfs_getFile( item->name() ).path( -1 ).local8Bit() );
TDEProcess proc;
{
- KConfigGroupSaver saver(krConfig, "General");
+ TDEConfigGroupSaver saver(krConfig, "General");
TQString term = krConfig->readEntry( "Terminal", _Terminal );
proc << KrServices::separateArgs( term );
if ( !panel->func->getVFile(item)->vfile_isDir() ) proc << "-e" << item->name();
diff --git a/krusader/Panel/krpreviewpopup.cpp b/krusader/Panel/krpreviewpopup.cpp
index ac86cc0..aceaf80 100644
--- a/krusader/Panel/krpreviewpopup.cpp
+++ b/krusader/Panel/krpreviewpopup.cpp
@@ -31,15 +31,15 @@ void KrPreviewPopup::setUrls(const KURL::List* urls){
//insertItem(i18n("Configure preview"),0);
insertItem(i18n("Preview not available"),0);
- KIO::PreviewJob* pjob;
- TQStringList plugins = KIO::PreviewJob::availablePlugins();
+ TDEIO::PreviewJob* pjob;
+ TQStringList plugins = TDEIO::PreviewJob::availablePlugins();
for( unsigned int i=0; i< urls->count(); ++i){
KFileItem* kfi = new KFileItem(KFileItem::Unknown,KFileItem::Unknown,*(urls->at(i)));
files.append(kfi);
}
- pjob = new KIO::PreviewJob(files,200,200,200,1,true,true,0);
+ pjob = new TDEIO::PreviewJob(files,200,200,200,1,true,true,0);
connect(pjob,TQT_SIGNAL(gotPreview(const KFileItem*,const TQPixmap&)),
this,TQT_SLOT(addPreview(const KFileItem*,const TQPixmap&)));
}
diff --git a/krusader/Panel/krview.cpp b/krusader/Panel/krview.cpp
index 8c7d733..b567f1d 100644
--- a/krusader/Panel/krview.cpp
+++ b/krusader/Panel/krview.cpp
@@ -66,8 +66,8 @@ void KrViewOperator::startDrag() {
// ----------------------------- krview
-KrView::KrView( KConfig *cfg ) : _config( cfg ), _widget(0), _nameToMakeCurrent( TQString() ), _nameToMakeCurrentIfAdded( TQString() ),
-_numSelected( 0 ), _count( 0 ), _numDirs( 0 ), _countSize( 0 ), _selectedSize( 0 ), _properties(0), _focused( false ), _nameInKConfig(TQString()) {
+KrView::KrView( TDEConfig *cfg ) : _config( cfg ), _widget(0), _nameToMakeCurrent( TQString() ), _nameToMakeCurrentIfAdded( TQString() ),
+_numSelected( 0 ), _count( 0 ), _numDirs( 0 ), _countSize( 0 ), _selectedSize( 0 ), _properties(0), _focused( false ), _nameInTDEConfig(TQString()) {
}
KrView::~KrView() {
@@ -79,8 +79,8 @@ KrView::~KrView() {
void KrView::init() {
// sanity checks:
- if (_nameInKConfig.isEmpty())
- tqFatal("_nameInKConfig must be set during construction of KrView inheritors");
+ if (_nameInTDEConfig.isEmpty())
+ tqFatal("_nameInTDEConfig must be set during construction of KrView inheritors");
if (!_widget)
tqFatal("_widget must be set during construction of KrView inheritors");
// ok, continue
@@ -163,9 +163,9 @@ TQString KrView::statistics() {
_countSize += it->getVfile()->vfile_getSize();
}
TQString tmp = TQString(i18n("%1 out of %2, %3 (%4) out of %5 (%6)"))
- .arg( _numSelected ).arg( _count ).arg( KIO::convertSize( _selectedSize ) )
+ .arg( _numSelected ).arg( _count ).arg( TDEIO::convertSize( _selectedSize ) )
.arg( KRpermHandler::parseSize(_selectedSize) )
- .arg( KIO::convertSize( _countSize ) ).arg( KRpermHandler::parseSize(_countSize) );
+ .arg( TDEIO::convertSize( _countSize ) ).arg( KRpermHandler::parseSize(_countSize) );
// notify if we're running a filtered view
if (filter() != KrViewProperties::All)
tmp = ">> [ " + filterMask().nameFilter() + " ] "+tmp;
@@ -173,7 +173,7 @@ TQString KrView::statistics() {
}
void KrView::changeSelection( const KRQuery& filter, bool select, bool includeDirs ) {
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
bool markDirs = _config->readBoolEntry( "Mark Dirs", _MarkDirs ) || includeDirs;
KrViewItem *temp = getCurrentKrViewItem();
@@ -205,7 +205,7 @@ void KrView::changeSelection( const KRQuery& filter, bool select, bool includeDi
}
void KrView::invertSelection() {
- KConfigGroupSaver grpSvr( _config, "Look&Feel" /*nameInKConfig()*/ );
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" /*nameInTDEConfig()*/ );
bool markDirs = _config->readBoolEntry( "Mark Dirs", _MarkDirs );
KrViewItem *temp = getCurrentKrViewItem();
diff --git a/krusader/Panel/krview.h b/krusader/Panel/krview.h
index d7523e9..353fcd9 100644
--- a/krusader/Panel/krview.h
+++ b/krusader/Panel/krview.h
@@ -171,7 +171,7 @@ public:
virtual void prepareForActive() { _focused = true; }
virtual void prepareForPassive() { _focused = false; }
virtual void renameCurrentItem(); // Rename current item. returns immediatly
- virtual TQString nameInKConfig() const { return _nameInKConfig; }
+ virtual TQString nameInTDEConfig() const { return _nameInTDEConfig; }
protected:
virtual KrViewItem *preAddItem(vfile *vf) = 0;
@@ -186,11 +186,11 @@ public:
virtual void updateItem(vfile *vf);
virtual void delItem(const TQString &name);
virtual uint numSelected() const { return _numSelected; }
- virtual KIO::filesize_t selectedSize() const { return _selectedSize; }
+ virtual TDEIO::filesize_t selectedSize() const { return _selectedSize; }
virtual uint numFiles() const { return _count-_numDirs; }
virtual uint numDirs() const { return _numDirs; }
virtual uint count() const { return _count; }
- virtual KIO::filesize_t countSize() const { return _countSize; }
+ virtual TDEIO::filesize_t countSize() const { return _countSize; }
virtual void getSelectedItems(TQStringList* names);
virtual void getItemsByMask(TQString mask, TQStringList* names, bool dirs = true, bool files = true);
virtual void getSelectedKrViewItems(KrViewItemList *items);
@@ -223,24 +223,24 @@ public:
// todo: what about selection modes ???
virtual ~KrView();
protected:
- KrView(KConfig *cfg = krConfig);
+ KrView(TDEConfig *cfg = krConfig);
static TQPixmap getIcon(vfile *vf);
void changeSelection(const KRQuery& filter, bool select, bool includeDirs = false);
protected:
- KConfig *_config;
+ TDEConfig *_config;
TQWidget *_widget;
TQString _nameToMakeCurrent;
TQString _nameToMakeCurrentIfAdded;
uint _numSelected, _count, _numDirs;
- KIO::filesize_t _countSize, _selectedSize;
+ TDEIO::filesize_t _countSize, _selectedSize;
bool _left;
KrViewProperties *_properties;
KrViewOperator *_operator;
TQDict<KrViewItem> _dict;
bool _focused;
- TQString _nameInKConfig;
+ TQString _nameInTDEConfig;
};
#endif /* KRVIEW_H */
diff --git a/krusader/Panel/krviewitem.cpp b/krusader/Panel/krviewitem.cpp
index 28f3a0c..c983f99 100644
--- a/krusader/Panel/krviewitem.cpp
+++ b/krusader/Panel/krviewitem.cpp
@@ -49,7 +49,7 @@ TQString KrViewItem::description() const {
TQString text = _vf->vfile_getName();
TQString comment = KMimeType::mimeType(_vf->vfile_getMime())->comment(text, false);
TQString myLinkDest = _vf->vfile_getSymDest();
- KIO::filesize_t mySize = _vf->vfile_getSize();
+ TDEIO::filesize_t mySize = _vf->vfile_getSize();
TQString text2 = text.copy();
mode_t m_fileMode = _vf->vfile_getMode();
@@ -66,7 +66,7 @@ TQString KrViewItem::description() const {
text += tmp;
} else if ( S_ISREG( m_fileMode ) ){
text = TQString("%1 (%2)").arg(text2).arg( PROPS->humanReadableSize ?
- KRpermHandler::parseSize(_vf->vfile_getSize()) : KIO::convertSize( mySize ) );
+ KRpermHandler::parseSize(_vf->vfile_getSize()) : TDEIO::convertSize( mySize ) );
text += " ";
text += comment;
} else if ( S_ISDIR ( m_fileMode ) ){
diff --git a/krusader/Panel/krviewitem.h b/krusader/Panel/krviewitem.h
index ad4c56b..b4c2381 100644
--- a/krusader/Panel/krviewitem.h
+++ b/krusader/Panel/krviewitem.h
@@ -62,7 +62,7 @@ public:
protected:
// used INTERNALLY when calculation of dir size changes the displayed size of the item
- inline void setSize(KIO::filesize_t size) { _vf->vfile_setSize(size); }
+ inline void setSize(TDEIO::filesize_t size) { _vf->vfile_setSize(size); }
vfile* _vf; // each view item holds a pointer to a corrosponding vfile for fast access
bool dummyVfile; // used in case our item represents the ".." (updir) item
diff --git a/krusader/Panel/listpanel.cpp b/krusader/Panel/listpanel.cpp
index 097e26c..9647b67 100644
--- a/krusader/Panel/listpanel.cpp
+++ b/krusader/Panel/listpanel.cpp
@@ -760,8 +760,8 @@ void ListPanel::gotStats( const TQString &mountPoint, unsigned long kBSize,
}
TQString stats = i18n( "%1 free out of %2 (%3%) on %4 [ (%5) ]" )
- .arg( KIO::convertSizeFromKB( kBAvail ) )
- .arg( KIO::convertSizeFromKB( kBSize ) ).arg( perc )
+ .arg( TDEIO::convertSizeFromKB( kBAvail ) )
+ .arg( TDEIO::convertSizeFromKB( kBSize ) ).arg( perc )
.arg( mountPoint ).arg( fstype );
status->setText( stats );
}
@@ -838,7 +838,7 @@ void ListPanel::handleDropOnView( TQDropEvent *e, TQWidget *widget ) {
break;
}
- KIO::CopyJob::CopyMode mode = KIO::CopyJob::Copy;
+ TDEIO::CopyJob::CopyMode mode = TDEIO::CopyJob::Copy;
// the KURL::List is finished, let's go
// --> display the COPY/MOVE/LINK menu
@@ -854,13 +854,13 @@ void ListPanel::handleDropOnView( TQDropEvent *e, TQWidget *widget ) {
int result = popup.exec( tmp );
switch ( result ) {
case 1 :
- mode = KIO::CopyJob::Copy;
+ mode = TDEIO::CopyJob::Copy;
break;
case 2 :
- mode = KIO::CopyJob::Move;
+ mode = TDEIO::CopyJob::Move;
break;
case 3 :
- mode = KIO::CopyJob::Link;
+ mode = TDEIO::CopyJob::Link;
break;
case - 1 : // user pressed outside the menu
case 4:
@@ -1038,7 +1038,7 @@ void ListPanel::panelInactive() {
func->files()->vfs_enableRefresh(false);
}
-void ListPanel::slotJobStarted(KIO::Job* job) {
+void ListPanel::slotJobStarted(TDEIO::Job* job) {
// disable the parts of the panel we don't want touched
//static_cast<KrDetailedView*>(view)->setEnabled(false);
status->setEnabled(false);
@@ -1054,14 +1054,14 @@ void ListPanel::slotJobStarted(KIO::Job* job) {
syncBrowseButton->setEnabled(false);
// connect to the job interface to provide in-panel refresh notification
- connect( job, TQT_SIGNAL( infoMessage( KIO::Job*, const TQString & ) ),
- TQT_SLOT( inlineRefreshInfoMessage( KIO::Job*, const TQString & ) ) );
- connect( job, TQT_SIGNAL( percent( KIO::Job*, unsigned long ) ),
- TQT_SLOT( inlineRefreshPercent( KIO::Job*, unsigned long ) ) );
- connect(job,TQT_SIGNAL(result(KIO::Job*)),
- this,TQT_SLOT(inlineRefreshListResult(KIO::Job*)));
- connect(job,TQT_SIGNAL(canceled(KIO::Job*)),
- this,TQT_SLOT(inlineRefreshListResult(KIO::Job*)));
+ connect( job, TQT_SIGNAL( infoMessage( TDEIO::Job*, const TQString & ) ),
+ TQT_SLOT( inlineRefreshInfoMessage( TDEIO::Job*, const TQString & ) ) );
+ connect( job, TQT_SIGNAL( percent( TDEIO::Job*, unsigned long ) ),
+ TQT_SLOT( inlineRefreshPercent( TDEIO::Job*, unsigned long ) ) );
+ connect(job,TQT_SIGNAL(result(TDEIO::Job*)),
+ this,TQT_SLOT(inlineRefreshListResult(TDEIO::Job*)));
+ connect(job,TQT_SIGNAL(canceled(TDEIO::Job*)),
+ this,TQT_SLOT(inlineRefreshListResult(TDEIO::Job*)));
inlineRefreshJob = job;
@@ -1076,16 +1076,16 @@ void ListPanel::inlineRefreshCancel() {
}
}
-void ListPanel::inlineRefreshPercent( KIO::Job*, unsigned long perc) {
+void ListPanel::inlineRefreshPercent( TDEIO::Job*, unsigned long perc) {
TQString msg = TQString(">> %1: %2 % complete...").arg(i18n("Reading")).arg(perc);
totals->setText(msg);
}
-void ListPanel::inlineRefreshInfoMessage( KIO::Job*, const TQString &msg ) {
+void ListPanel::inlineRefreshInfoMessage( TDEIO::Job*, const TQString &msg ) {
totals->setText(">> " + i18n("Reading: ") + msg);
}
-void ListPanel::inlineRefreshListResult(KIO::Job*) {
+void ListPanel::inlineRefreshListResult(TDEIO::Job*) {
inlineRefreshJob = 0;
// reenable everything
//static_cast<KrDetailedView*>(view)->setEnabled(true);
diff --git a/krusader/Panel/listpanel.h b/krusader/Panel/listpanel.h
index e88c375..c48b20d 100644
--- a/krusader/Panel/listpanel.h
+++ b/krusader/Panel/listpanel.h
@@ -153,10 +153,10 @@ protected slots:
void handleDropOnStatus( TQDropEvent * ); // handles drops on the status line
void startDragging( TQStringList, TQPixmap );
// those handle the in-panel refresh notifications
- void slotJobStarted(KIO::Job* job);
- void inlineRefreshInfoMessage( KIO::Job* job, const TQString &msg );
- void inlineRefreshListResult(KIO::Job* job);
- void inlineRefreshPercent( KIO::Job*, unsigned long );
+ void slotJobStarted(TDEIO::Job* job);
+ void inlineRefreshInfoMessage( TDEIO::Job* job, const TQString &msg );
+ void inlineRefreshListResult(TDEIO::Job* job);
+ void inlineRefreshPercent( TDEIO::Job*, unsigned long );
void inlineRefreshCancel();
signals:
@@ -195,7 +195,7 @@ public:
MediaButton *mediaButton;
SyncBrowseButton *syncBrowseButton;
KPushButton *inlineRefreshCancelButton;
- KIO::Job *inlineRefreshJob;
+ TDEIO::Job *inlineRefreshJob;
TQSplitter *splt;
TQHeader * header;
diff --git a/krusader/Panel/panelfunc.cpp b/krusader/Panel/panelfunc.cpp
index 89e5685..82cbc61 100755
--- a/krusader/Panel/panelfunc.cpp
+++ b/krusader/Panel/panelfunc.cpp
@@ -167,8 +167,8 @@ void ListPanelFunc::immediateOpenUrl( const KURL& urlIn ) {
return;
}
}
- connect( files(), TQT_SIGNAL(startJob(KIO::Job* )),
- panel, TQT_SLOT(slotJobStarted(KIO::Job* )));
+ connect( files(), TQT_SIGNAL(startJob(TDEIO::Job* )),
+ panel, TQT_SLOT(slotJobStarted(TDEIO::Job* )));
if ( vfsP->vfs_refresh( u ) ) {
break; // we have a valid refreshed URL now
}
@@ -448,23 +448,23 @@ void ListPanelFunc::moveFiles() {
if( !virtualBaseURL.isEmpty() ) {
// keep the directory structure for virtual paths
- VirtualCopyJob *vjob = new VirtualCopyJob( &fileNames, files(), dest, virtualBaseURL, pmode, KIO::CopyJob::Move, false, true );
- connect( vjob, TQT_SIGNAL( result( KIO::Job* ) ), this, TQT_SLOT( refresh() ) );
+ VirtualCopyJob *vjob = new VirtualCopyJob( &fileNames, files(), dest, virtualBaseURL, pmode, TDEIO::CopyJob::Move, false, true );
+ connect( vjob, TQT_SIGNAL( result( TDEIO::Job* ) ), this, TQT_SLOT( refresh() ) );
if ( dest.equals( panel->otherPanel->virtualPath(), true ) )
- connect( vjob, TQT_SIGNAL( result( KIO::Job* ) ), panel->otherPanel->func, TQT_SLOT( refresh() ) );
+ connect( vjob, TQT_SIGNAL( result( TDEIO::Job* ) ), panel->otherPanel->func, TQT_SLOT( refresh() ) );
}
// if we are not moving to the other panel :
else if ( !dest.equals( panel->otherPanel->virtualPath(), true ) ) {
// you can rename only *one* file not a batch,
// so a batch dest must alwayes be a directory
if ( fileNames.count() > 1 ) dest.adjustPath(1);
- KIO::Job* job = PreservingCopyJob::createCopyJob( pmode, *fileUrls, dest, KIO::CopyJob::Move, false, true );
+ TDEIO::Job* job = PreservingCopyJob::createCopyJob( pmode, *fileUrls, dest, TDEIO::CopyJob::Move, false, true );
job->setAutoErrorHandlingEnabled( true );
// refresh our panel when done
- connect( job, TQT_SIGNAL( result( KIO::Job* ) ), this, TQT_SLOT( refresh() ) );
+ connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ), this, TQT_SLOT( refresh() ) );
// and if needed the other panel as well
if ( dest.equals( panel->otherPanel->virtualPath(), true ) )
- connect( job, TQT_SIGNAL( result( KIO::Job* ) ), panel->otherPanel->func, TQT_SLOT( refresh() ) );
+ connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ), panel->otherPanel->func, TQT_SLOT( refresh() ) );
} else { // let the other panel do the dirty job
//check if copy is supported
@@ -473,7 +473,7 @@ void ListPanelFunc::moveFiles() {
return ;
}
// finally..
- otherFunc() ->files() ->vfs_addFiles( fileUrls, KIO::CopyJob::Move, files(), "", pmode );
+ otherFunc() ->files() ->vfs_addFiles( fileUrls, TDEIO::CopyJob::Move, files(), "", pmode );
}
}
@@ -596,22 +596,22 @@ void ListPanelFunc::copyFiles() {
if( !virtualBaseURL.isEmpty() ) {
// keep the directory structure for virtual paths
- VirtualCopyJob *vjob = new VirtualCopyJob( &fileNames, files(), dest, virtualBaseURL, pmode, KIO::CopyJob::Copy, false, true );
- connect( vjob, TQT_SIGNAL( result( KIO::Job* ) ), this, TQT_SLOT( refresh() ) );
+ VirtualCopyJob *vjob = new VirtualCopyJob( &fileNames, files(), dest, virtualBaseURL, pmode, TDEIO::CopyJob::Copy, false, true );
+ connect( vjob, TQT_SIGNAL( result( TDEIO::Job* ) ), this, TQT_SLOT( refresh() ) );
if ( dest.equals( panel->otherPanel->virtualPath(), true ) )
- connect( vjob, TQT_SIGNAL( result( KIO::Job* ) ), panel->otherPanel->func, TQT_SLOT( refresh() ) );
+ connect( vjob, TQT_SIGNAL( result( TDEIO::Job* ) ), panel->otherPanel->func, TQT_SLOT( refresh() ) );
}
// if we are not copying to the other panel :
else if ( !dest.equals( panel->otherPanel->virtualPath(), true ) ) {
// you can rename only *one* file not a batch,
// so a batch dest must alwayes be a directory
if ( fileNames.count() > 1 ) dest.adjustPath(1);
- KIO::Job* job = PreservingCopyJob::createCopyJob( pmode, *fileUrls, dest, KIO::CopyJob::Copy, false, true );
+ TDEIO::Job* job = PreservingCopyJob::createCopyJob( pmode, *fileUrls, dest, TDEIO::CopyJob::Copy, false, true );
job->setAutoErrorHandlingEnabled( true );
if ( dest.equals( panel->virtualPath(), true ) ||
dest.upURL().equals( panel->virtualPath(), true ) )
// refresh our panel when done
- connect( job, TQT_SIGNAL( result( KIO::Job* ) ), this, TQT_SLOT( refresh() ) );
+ connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ), this, TQT_SLOT( refresh() ) );
// let the other panel do the dirty job
} else {
//check if copy is supported
@@ -620,7 +620,7 @@ void ListPanelFunc::copyFiles() {
return ;
}
// finally..
- otherFunc() ->files() ->vfs_addFiles( fileUrls, KIO::CopyJob::Copy, 0, "", pmode );
+ otherFunc() ->files() ->vfs_addFiles( fileUrls, TDEIO::CopyJob::Copy, 0, "", pmode );
}
}
@@ -820,7 +820,7 @@ void ListPanelFunc::pack() {
// get the files to be packed:
files() ->vfs_getFiles( &fileNames );
- KIO::filesize_t totalSize = 0;
+ TDEIO::filesize_t totalSize = 0;
unsigned long totalDirs = 0, totalFiles = 0;
if( !calcSpace( fileNames, totalSize, totalFiles, totalDirs ) )
return;
@@ -836,7 +836,7 @@ void ListPanelFunc::pack() {
tempDir->setAutoDelete( true );
arcDir = tempDir->name();
KURL::List *urlList = files() ->vfs_getFiles( &fileNames );
- KIO::NetAccess::dircopy( *urlList, vfs::fromPathOrURL( arcDir ), 0 );
+ TDEIO::NetAccess::dircopy( *urlList, vfs::fromPathOrURL( arcDir ), 0 );
delete urlList;
}
@@ -853,7 +853,7 @@ void ListPanelFunc::pack() {
// copy from the temp file to it's right place
if ( tempDestFile ) {
- KIO::NetAccess::file_move( vfs::fromPathOrURL( arcFile ), destURL );
+ TDEIO::NetAccess::file_move( vfs::fromPathOrURL( arcFile ), destURL );
delete tempDestFile;
}
@@ -874,7 +874,7 @@ void ListPanelFunc::testArchive() {
// download the file if it's on a remote filesystem
if ( !arcURL.isLocalFile() ) {
url = locateLocal( "tmp", TQString( arcName ) );
- if ( !KIO::NetAccess::download( arcURL, url, 0 ) ) {
+ if ( !TDEIO::NetAccess::download( arcURL, url, 0 ) ) {
KMessageBox::sorry( krApp, i18n( "Krusader is unable to download: " ) + arcURL.fileName() );
return ;
}
@@ -935,7 +935,7 @@ void ListPanelFunc::unpack() {
TQString url = TQString();
if ( !arcURL.isLocalFile() ) {
url = locateLocal( "tmp", TQString( arcName ) );
- if ( !KIO::NetAccess::download( arcURL, url, 0 ) ) {
+ if ( !TDEIO::NetAccess::download( arcURL, url, 0 ) ) {
KMessageBox::sorry( krApp, i18n( "Krusader is unable to download: " ) + arcURL.fileName() );
continue;
}
@@ -982,7 +982,7 @@ void ListPanelFunc::unpack() {
if ( nameList[ i ] != "." && nameList[ i ] != ".." )
urlList.append( vfs::fromPathOrURL( dest.path( 1 ) + nameList[ i ] ) );
if ( urlList.count() > 0 )
- KIO::NetAccess::dircopy( urlList, originalDestURL, 0 );
+ TDEIO::NetAccess::dircopy( urlList, originalDestURL, 0 );
delete tempDir;
}
}
@@ -1044,7 +1044,7 @@ void ListPanelFunc::calcSpace() {
panel->slotUpdateTotals();
}
-bool ListPanelFunc::calcSpace( const TQStringList & items, KIO::filesize_t & totalSize, unsigned long & totalFiles, unsigned long & totalDirs ) {
+bool ListPanelFunc::calcSpace( const TQStringList & items, TDEIO::filesize_t & totalSize, unsigned long & totalFiles, unsigned long & totalDirs ) {
KrCalcSpaceDialog calc( krApp, panel, items, true );
calc.exec();
totalSize = calc.getTotalSize();
@@ -1178,7 +1178,7 @@ void ListPanelFunc::pasteFromClipboard() {
KURL destUrl = panel->virtualPath();
- files()->vfs_addFiles( &urls, cutSelection ? KIO::CopyJob::Move : KIO::CopyJob::Copy, otherFunc()->files(),
+ files()->vfs_addFiles( &urls, cutSelection ? TDEIO::CopyJob::Move : TDEIO::CopyJob::Copy, otherFunc()->files(),
"", PM_DEFAULT );
}
}
diff --git a/krusader/Panel/panelfunc.h b/krusader/Panel/panelfunc.h
index c85e6fa..3099762 100644
--- a/krusader/Panel/panelfunc.h
+++ b/krusader/Panel/panelfunc.h
@@ -85,7 +85,7 @@ public:
// calculate the occupied space. A dialog appears, if calculation lasts more than 3 seconds
// and disappears, if the calculation is done. Returns true, if the result is ok and false
// otherwise (Cancel was pressed).
- bool calcSpace(const TQStringList & items,KIO::filesize_t & totalSize,unsigned long & totalFiles,unsigned long & totalDirs);
+ bool calcSpace(const TQStringList & items,TDEIO::filesize_t & totalSize,unsigned long & totalFiles,unsigned long & totalDirs);
void FTPDisconnect();
void newFTPconnection();
inline ListPanelFunc* otherFunc(){ return panel->otherPanel->func; }
diff --git a/krusader/Panel/panelpopup.cpp b/krusader/Panel/panelpopup.cpp
index 6027d86..7349686 100644
--- a/krusader/Panel/panelpopup.cpp
+++ b/krusader/Panel/panelpopup.cpp
@@ -380,16 +380,16 @@ void PanelPopup::slotDroppedOnTree(TQWidget *widget, TQDropEvent *e, KURL::List
TQPoint tmp = widget->mapToGlobal( e->pos() );
int result = popup.exec( TQCursor::pos() );
- KIO::CopyJob *job;
+ TDEIO::CopyJob *job;
switch ( result ) {
case 1 :
- job = KIO::copy(lst, dest, true);
+ job = TDEIO::copy(lst, dest, true);
break;
case 2 :
- job = KIO::move(lst, dest, true);
+ job = TDEIO::move(lst, dest, true);
break;
case 3 :
- job = KIO::link(lst, dest, true);
+ job = TDEIO::link(lst, dest, true);
break;
case - 1 : // user pressed outside the menu
case 4:
diff --git a/krusader/Panel/panelpopup.h b/krusader/Panel/panelpopup.h
index 8062948..dddd125 100644
--- a/krusader/Panel/panelpopup.h
+++ b/krusader/Panel/panelpopup.h
@@ -59,7 +59,7 @@ protected:
TQWidgetStack *stack;
KrusaderImageFilePreview *viewer;
KrSqueezedTextLabel *dataLine;
- TQGuardedPtr<KIO::PreviewJob> pjob;
+ TQGuardedPtr<TDEIO::PreviewJob> pjob;
KFileTreeView *tree;
TQToolButton *treeBtn, *previewBtn, *quickBtn, *viewerBtn, *duBtn;
TQButtonGroup *btns;
diff --git a/krusader/Panel/krbriefview.cpp b/krusader/Panel/krbriefview.cpp
index 256d1aa..aadd05f 100644
--- a/krusader/Panel/krbriefview.cpp
+++ b/krusader/Panel/krbriefview.cpp
@@ -79,11 +79,11 @@ void KrBriefViewToolTip::maybeTip( const TQPoint &pos )
}
-KrBriefView::KrBriefView( TQHeader * headerIn, TQWidget *parent, bool &left, KConfig *cfg, const char *name ):
+KrBriefView::KrBriefView( TQHeader * headerIn, TQWidget *parent, bool &left, TDEConfig *cfg, const char *name ):
KIconView(parent, name), KrView( cfg ), header( headerIn ), _currDragItem( 0 ),
currentlyRenamedItem( 0 ), pressedItem( 0 ), mouseEvent( 0 ) {
setWidget( this );
- _nameInKConfig = TQString( "KrBriefView" ) + TQString( ( left ? "Left" : "Right" ) );
+ _nameInTDEConfig = TQString( "KrBriefView" ) + TQString( ( left ? "Left" : "Right" ) );
krConfig->setGroup("Private");
if (krConfig->readBoolEntry("Enable Input Method", true))
setInputMethodEnabled(true);
@@ -93,8 +93,8 @@ KrBriefView::KrBriefView( TQHeader * headerIn, TQWidget *parent, bool &left, KCo
void KrBriefView::setup() {
lastSwushPosition = 0;
- // use the {} so that KConfigGroupSaver will work correctly!
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ // use the {} so that TDEConfigGroupSaver will work correctly!
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
setFont( _config->readFontEntry( "Filelist Font", _FilelistFont ) );
// decide on single click/double click selection
if ( _config->readBoolEntry( "Single Click Selects", _SingleClickSelects ) &&
@@ -118,7 +118,7 @@ void KrBriefView::setup() {
connect( &KrColorCache::getColorCache(), TQT_SIGNAL( colorsRefreshed() ), this, TQT_SLOT( refreshColors() ) );
// add whatever columns are needed to the listview
- krConfig->setGroup( nameInKConfig() );
+ krConfig->setGroup( nameInTDEConfig() );
// determine basic settings for the view
setAcceptDrops( true );
@@ -341,7 +341,7 @@ void KrBriefView::slotClicked( TQIconViewItem *item ) {
if ( !modifierPressed ) {
if ( singleClicked && !renameTimer.isActive() ) {
- KConfig * config = TDEGlobal::config();
+ TDEConfig * config = TDEGlobal::config();
config->setGroup( "KDE" );
int doubleClickInterval = config->readNumEntry( "DoubleClickInterval", 400 );
@@ -378,7 +378,7 @@ void KrBriefView::prepareForActive() {
void KrBriefView::prepareForPassive() {
KrView::prepareForPassive();
CANCEL_TWO_CLICK_RENAME;
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
if ( _config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) ) {
if ( MAIN_VIEW ) {
if ( ACTIVE_PANEL ) {
@@ -537,7 +537,7 @@ void KrBriefView::contentsMousePressEvent( TQMouseEvent * e ) {
}
// stop quick search in case a mouse click occured
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
if ( _config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) ) {
if ( MAIN_VIEW ) {
if ( ACTIVE_PANEL ) {
@@ -792,7 +792,7 @@ void KrBriefView::imStartEvent(TQIMEvent* e)
ACTIVE_PANEL->quickSearch->myIMStartEvent( e );
return ;
}else {
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
if ( !_config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) )
KIconView::imStartEvent( e );
else {
@@ -1098,7 +1098,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
//if ( _config->readBoolEntry( "Do Quicksearch", _DoQuicksearch ) ) {
// are we using krusader's classic quicksearch, or wincmd style?
{
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
if ( !_config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) )
KIconView::keyPressEvent( e );
else {
@@ -1155,7 +1155,7 @@ void KrBriefView::renameCurrentItem() {
rename( static_cast<TQIconViewItem*>( it ) );
// if applicable, select only the name without extension
/* TODO:
- KConfigGroupSaver svr(krConfig,"Look&Feel");
+ TDEConfigGroupSaver svr(krConfig,"Look&Feel");
if (!krConfig->readBoolEntry("Rename Selects Extension", true)) {
if (it->hasExtension() && !it->VF->vfile_isDir() )
renameLineEdit()->setSelection(0, it->name().findRev(it->extension())-1);
@@ -1181,7 +1181,7 @@ void KrBriefView::quickSearch( const TQString & str, int direction ) {
KrViewItem * item = getCurrentKrViewItem();
if (!item)
return;
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
bool caseSensitive = _config->readBoolEntry( "Case Sensitive Quicksearch", _CaseSensitiveQuicksearch );
if ( !direction ) {
if ( caseSensitive ? item->name().startsWith( str ) : item->name().lower().startsWith( str.lower() ) )
@@ -1303,7 +1303,7 @@ void KrBriefView::initProperties() {
_properties = new KrBriefViewProperties;
_properties->filter = KrViewProperties::All;
_properties->filterMask = KRQuery( "*" );
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
_properties->displayIcons = _config->readBoolEntry( "With Icons", _WithIcons );
bool dirsByNameAlways = _config->readBoolEntry("Always sort dirs by name", false);
_properties->sortMode = static_cast<KrViewProperties::SortSpec>( KrViewProperties::Name |
@@ -1335,7 +1335,7 @@ void KrBriefView::initProperties() {
}
_properties->atomicExtensions = atomicExtensions;
- _config->setGroup( nameInKConfig() );
+ _config->setGroup( nameInTDEConfig() );
PROPS->numberOfColumns = _config->readNumEntry( "Number Of Brief Columns", _NumberOfBriefColumns );
if( PROPS->numberOfColumns < 1 )
PROPS->numberOfColumns = 1;
@@ -1358,7 +1358,7 @@ void KrBriefView::setColumnNr()
int result=popup.exec(TQCursor::pos());
- krConfig->setGroup( nameInKConfig() );
+ krConfig->setGroup( nameInTDEConfig() );
if( result > COL_ID && result <= COL_ID + MAX_COLS )
{
diff --git a/krusader/Panel/krdetailedview.cpp b/krusader/Panel/krdetailedview.cpp
index 708970d..0400f82 100644
--- a/krusader/Panel/krdetailedview.cpp
+++ b/krusader/Panel/krdetailedview.cpp
@@ -55,7 +55,7 @@ YP YD 88 YD ~Y8888P' `8888Y' YP YP Y8888D' Y88888P 88 YD
#include <tqdict.h>
//////////////////////////////////////////////////////////////////////////
// The following is KrDetailedView's settings in KConfig:
// Group name: KrDetailedView
//
// Ext Column
@@ -87,11 +87,11 @@ YP YD 88 YD ~Y8888P' `8888Y' YP YP Y8888D' Y88888P 88 YD
TQString KrDetailedView::ColumnName[ KrDetailedViewProperties::MAX_COLUMNS ];
-KrDetailedView::KrDetailedView( TQWidget *parent, bool &left, KConfig *cfg, const char *name ) :
+KrDetailedView::KrDetailedView( TQWidget *parent, bool &left, TDEConfig *cfg, const char *name ) :
KListView( parent, name ), KrView( cfg ), _currDragItem( 0L ), currentlyRenamedItem( 0 ),
pressedItem( 0 ) {
setWidget( this );
- _nameInKConfig=TQString( "KrDetailedView" ) + TQString( ( left ? "Left" : "Right" ) ) ;
+ _nameInTDEConfig=TQString( "KrDetailedView" ) + TQString( ( left ? "Left" : "Right" ) ) ;
krConfig->setGroup("Private");
if (krConfig->readBoolEntry("Enable Input Method", true))
setInputMethodEnabled(true);
@@ -112,8 +112,8 @@ void KrDetailedView::setup() {
}
/////////////////////////////// listview ////////////////////////////////////
- { // use the {} so that KConfigGroupSaver will work correctly!
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ { // use the {} so that TDEConfigGroupSaver will work correctly!
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
setFont( _config->readFontEntry( "Filelist Font", _FilelistFont ) );
// decide on single click/double click selection
if ( _config->readBoolEntry( "Single Click Selects", _SingleClickSelects ) &&
@@ -139,7 +139,7 @@ void KrDetailedView::setup() {
}
// add whatever columns are needed to the listview
- krConfig->setGroup( nameInKConfig() );
+ krConfig->setGroup( nameInTDEConfig() );
newColumn( KrDetailedViewProperties::Name ); // we always have a name
setColumnWidthMode( COLUMN(Name), TQListView::Manual );
@@ -431,7 +431,7 @@ void KrDetailedView::slotClicked( TQListViewItem *item ) {
if ( !modifierPressed ) {
if ( singleClicked && !renameTimer.isActive() ) {
- KConfig * config = TDEGlobal::config();
+ TDEConfig * config = TDEGlobal::config();
config->setGroup( "KDE" );
int doubleClickInterval = config->readNumEntry( "DoubleClickInterval", 400 );
@@ -470,7 +470,7 @@ void KrDetailedView::prepareForPassive() {
CANCEL_TWO_CLICK_RENAME;
if ( renameLineEdit() ->isVisible() )
renameLineEdit() ->clearFocus();
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
if ( _config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) ) {
if ( MAIN_VIEW ) {
if ( ACTIVE_PANEL ) {
@@ -627,7 +627,7 @@ void KrDetailedView::contentsMousePressEvent( TQMouseEvent * e ) {
}
// stop quick search in case a mouse click occured
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
if ( _config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) ) {
if ( MAIN_VIEW ) {
if ( ACTIVE_PANEL ) {
@@ -862,7 +862,7 @@ void KrDetailedView::imStartEvent(TQIMEvent* e)
ACTIVE_PANEL->quickSearch->myIMStartEvent( e );
return ;
}else {
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
if ( !_config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) )
KListView::imStartEvent( e );
else {
@@ -1092,7 +1092,7 @@ void KrDetailedView::keyPressEvent( TQKeyEvent * e ) {
// there's a folder we can't enter (permissions). in that case, the returned
// size will not be correct.
//
- KIO::filesize_t totalSize = 0;
+ TDEIO::filesize_t totalSize = 0;
unsigned long totalFiles = 0, totalDirs = 0;
TQStringList items;
items.push_back( viewItem->name() );
@@ -1135,7 +1135,7 @@ mark: if (KrSelectionMode::getSelectionHandler()->spaceMovesDown())
//if ( _config->readBoolEntry( "Do Quicksearch", _DoQuicksearch ) ) {
// are we using krusader's classic quicksearch, or wincmd style?
{
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
if ( !_config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) )
KListView::keyPressEvent( e );
else {
@@ -1212,7 +1212,7 @@ void KrDetailedView::renameCurrentItem() {
if ( c >= 0 ) {
rename( static_cast<TQListViewItem*>( it ), c );
// if applicable, select only the name without extension
- KConfigGroupSaver svr(krConfig,"Look&Feel");
+ TDEConfigGroupSaver svr(krConfig,"Look&Feel");
if (!krConfig->readBoolEntry("Rename Selects Extension", true)) {
if (it->hasExtension() && !it->VF->vfile_isDir() )
renameLineEdit()->setSelection(0, it->name().findRev(it->extension())-1);
@@ -1272,7 +1272,7 @@ void KrDetailedView::quickSearch( const TQString & str, int direction ) {
KrViewItem * item = getCurrentKrViewItem();
if (!item)
return;
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
bool caseSensitive = _config->readBoolEntry( "Case Sensitive Quicksearch", _CaseSensitiveQuicksearch );
if ( !direction ) {
if ( caseSensitive ? item->name().startsWith( str ) : item->name().lower().startsWith( str.lower() ) )
@@ -1396,7 +1396,7 @@ void KrDetailedView::initOperator() {
void KrDetailedView::initProperties() {
_properties = new KrDetailedViewProperties;
- KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+ TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
for (int i=0; i<KrDetailedViewProperties::MAX_COLUMNS;++i)
PROPS->column[i]=-1;
PROPS->displayIcons = _config->readBoolEntry( "With Icons", _WithIcons );
@@ -1473,7 +1473,7 @@ void KrDetailedView::selectColumns()
int result=popup.exec(TQCursor::pos());
- krConfig->setGroup( nameInKConfig() );
+ krConfig->setGroup( nameInTDEConfig() );
switch( result - COLUMN_POPUP_IDS )
{
@@ -55,7 +55,7 @@ YP YD 88 YD ~Y8888P' `8888Y' YP YP Y8888D' Y88888P 88 YD
#include <tqdict.h>
//////////////////////////////////////////////////////////////////////////
-// The following is KrDetailedView's settings in KConfig:
+// The following is KrDetailedView's settings in TDEConfig:
// Group name: KrDetailedView
//